# imghst
***

A simple and fast image hoster for applications like ShareX.

***

### What does it do?
***
Literally just upload files. That's it. 

### How to configure?
***
Should be as simple as reading ``app/configuration/configuration.py``. You should be able to figure it out.